Index: /misc/tools/PersistenceCodeFix/PersistenceCodeFix/PersistenceCodeFix.Vsix/PersistenceCodeFix.Vsix.csproj
===================================================================
--- /misc/tools/PersistenceCodeFix/PersistenceCodeFix/PersistenceCodeFix.Vsix/PersistenceCodeFix.Vsix.csproj	(revision 16468)
+++ /misc/tools/PersistenceCodeFix/PersistenceCodeFix/PersistenceCodeFix.Vsix/PersistenceCodeFix.Vsix.csproj	(revision 16469)
@@ -3,6 +3,11 @@
 <Project ToolsVersion="14.0" DefaultTargets="Build" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
   <PropertyGroup>
-    <MinimumVisualStudioVersion>14.0</MinimumVisualStudioVersion>
+    <MinimumVisualStudioVersion>15.0</MinimumVisualStudioVersion>
     <VSToolsPath Condition="'$(VSToolsPath)' == ''">$(MSBuildExtensionsPath32)\Microsoft\VisualStudio\v$(VisualStudioVersion)</VSToolsPath>
+    <FileUpgradeFlags>
+    </FileUpgradeFlags>
+    <UpgradeBackupLocation>
+    </UpgradeBackupLocation>
+    <OldToolsVersion>14.0</OldToolsVersion>
   </PropertyGroup>
   <Import Project="$(MSBuildExtensionsPath)\$(MSBuildToolsVersion)\Microsoft.Common.props" Condition="Exists('$(MSBuildExtensionsPath)\$(MSBuildToolsVersion)\Microsoft.Common.props')" />
Index: /misc/tools/PersistenceCodeFix/PersistenceCodeFix/PersistenceCodeFix/Analyzers/MissingStorableConstructor/MissingStorableConstructorAnalyzer.cs
===================================================================
--- /misc/tools/PersistenceCodeFix/PersistenceCodeFix/PersistenceCodeFix/Analyzers/MissingStorableConstructor/MissingStorableConstructorAnalyzer.cs	(revision 16468)
+++ /misc/tools/PersistenceCodeFix/PersistenceCodeFix/PersistenceCodeFix/Analyzers/MissingStorableConstructor/MissingStorableConstructorAnalyzer.cs	(revision 16469)
@@ -14,5 +14,5 @@
     private const string Category = nameof(DiagnosticCategory.Persistence);
 
-    private static DiagnosticDescriptor Rule = new DiagnosticDescriptor(DiagnosticId, Title, MessageFormat, Category, DiagnosticSeverity.Error, isEnabledByDefault: true, description: Description);
+    private static DiagnosticDescriptor Rule = new DiagnosticDescriptor(DiagnosticId, Title, MessageFormat, Category, DiagnosticSeverity.Warning, isEnabledByDefault: true, description: Description);
 
     public override ImmutableArray<DiagnosticDescriptor> SupportedDiagnostics { get { return ImmutableArray.Create(Rule); } }
@@ -25,5 +25,5 @@
       var namedTypeSymbol = (INamedTypeSymbol)context.Symbol;
       if (namedTypeSymbol.IsStatic) return;
-      if (namedTypeSymbol.TypeKind == TypeKind.Delegate || namedTypeSymbol.TypeKind == TypeKind.Enum) return;
+      if (namedTypeSymbol.TypeKind == TypeKind.Delegate || namedTypeSymbol.TypeKind == TypeKind.Enum || namedTypeSymbol.TypeKind == TypeKind.Struct || namedTypeSymbol.TypeKind == TypeKind.Interface) return;
 
       var attr = context.Symbol.GetAttributes();
Index: /misc/tools/PersistenceCodeFix/PersistenceCodeFix/PersistenceCodeFix/Analyzers/MissingStorableType/MissingStorableTypeFix.cs
===================================================================
--- /misc/tools/PersistenceCodeFix/PersistenceCodeFix/PersistenceCodeFix/Analyzers/MissingStorableType/MissingStorableTypeFix.cs	(revision 16468)
+++ /misc/tools/PersistenceCodeFix/PersistenceCodeFix/PersistenceCodeFix/Analyzers/MissingStorableType/MissingStorableTypeFix.cs	(revision 16469)
@@ -100,8 +100,8 @@
       var newRoot = root.ReplaceNode(baseTypeDecl, newBaseTypeDecl);
 
       // add using of HeuristicLab.Persistence if the document does not already have it 
       var oldUsings = root.Usings;
-      if (oldUsings.All(x => x.Name.WithoutTrivia().ToString() != "HeuristicLab.Persistence")) {
-        var persistenceUsing = SyntaxFactory.UsingDirective(SyntaxFactory.IdentifierName("HeuristicLab.Persistence"));
+      if (oldUsings.All(x => x.Name.WithoutTrivia().ToString() != "HEAL.Fossil")) {
+        var persistenceUsing = SyntaxFactory.UsingDirective(SyntaxFactory.IdentifierName("HEAL.Fossil"));
         newRoot = newRoot.WithUsings(oldUsings.Add(persistenceUsing));
       }
@@ -100,8 +100,8 @@
       var newRoot = root.ReplaceNode(baseTypeDecl, newBaseTypeDecl);
 
-      // add using of HeuristicLab.Persistence if the document does not already have it 
+      // add using of HEAL.Fossil if the document does not already have it 
       var oldUsings = root.Usings;
Index: /misc/tools/PersistenceCodeFix/PersistenceCodeFix/PersistenceCodeFix/Analyzers/ObsoleteStorableClass/ObsoleteStorableClassFix.cs
===================================================================
--- /misc/tools/PersistenceCodeFix/PersistenceCodeFix/PersistenceCodeFix/Analyzers/ObsoleteStorableClass/ObsoleteStorableClassFix.cs	(revision 16468)
+++ /misc/tools/PersistenceCodeFix/PersistenceCodeFix/PersistenceCodeFix/Analyzers/ObsoleteStorableClass/ObsoleteStorableClassFix.cs	(revision 16469)
@@ -82,8 +82,8 @@
       var newRoot = root.ReplaceNode(attrDecl, newAttrDecl);
 
       // add using of HeuristicLab.Persistence if the document does not already have it 
       var oldUsings = root.Usings;
-      if (oldUsings.All(x => x.Name.WithoutTrivia().ToString() != "HeuristicLab.Persistence")) {
-        var persistenceUsing = SyntaxFactory.UsingDirective(SyntaxFactory.IdentifierName("HeuristicLab.Persistence"));
+      if (oldUsings.All(x => x.Name.WithoutTrivia().ToString() != "HEAL.Fossil")) {
+        var persistenceUsing = SyntaxFactory.UsingDirective(SyntaxFactory.IdentifierName("HEAL.Fossil"));
         newRoot = newRoot.WithUsings(oldUsings.Add(persistenceUsing));
       }
@@ -82,8 +82,8 @@
       var newRoot = root.ReplaceNode(attrDecl, newAttrDecl);
 
-      // add using of HeuristicLab.Persistence if the document does not already have it 
+      // add using of HEAL.Fossil if the document does not already have it 
       var oldUsings = root.Usings;
